# Pycovid-19

COVID-19 Python plots and maps

This small package allows for downloading and plotting
covid-19 confirmed cases, recovered and deaths from data
gathered by the [John Hopkins University](https://github.com/CSSEGISandData/COVID-19).
It allows for country evolutions to be compared between
them, as well as for prevalence to be calculated.
 
## Basic usage

See jupyter [notebook](https://nbviewer.jupyter.org/github/benjaminpillot/jupyter-notebooks/blob/master/covid-notebook.ipynb)

## See also
Louis Gastiaux's [package](https://framagit.org/lgostiau/covid19_display)